import bb.cascades 1.2
import bb.cascades.maps 1.0
import QtMobilitySubset.location 1.1
import bb.cascades.pickers 1.0

Sheet {
    peekEnabled: false
    Page {
        id: page1
        titleBar: TitleBar {
            title: qsTr("Set Location") + Retranslate.onLanguageChanged	            
            visibility: ChromeVisibility.Visible
            acceptAction: ActionItem {
                title: qsTr("Save") + Retranslate.onLanguageChanged	            
                onTriggered: {
                    _newLocation.saveLocation()
                }
            
            }
            
            dismissAction: ActionItem {
                title: qsTr("Cancel") + Retranslate.onLanguageChanged	            
                onTriggered: {
                    _newLocation.cancelLocation()
                }
            
            }
        
        } // title

        Container {
            id: root
            layout: DockLayout {
            }
            //! [1]
            MapView {
                id: mapview
                altitude: 3000
                //            latitude: 43.449488
                //           longitude: -80.406777
                preferredWidth: 1440
                preferredHeight: 1440
                objectName: "mapview"
                onCaptionButtonClicked: {
                    _newLocation.map_route()
                }
                
                onMapLongPressed: {
                    _newLocation.map_drawCircle(coordinates)
                }
            
            }
            
            Container {
                id: battery_warning
                leftPadding: 10
                rightPadding: 10
                topPadding: 15
                bottomPadding: 15
                layout: StackLayout {
                    orientation: LayoutOrientation.LeftToRight
                }
                
                verticalAlignment: VerticalAlignment.Bottom
                enabled: false
                objectName: "container_set_distance"
                // The minimum position of the slider means night-time so an image of a
                // moon is added to illustrate this.
                ImageView {
                    imageSource: "asset:///images/ic_zoom_out.png"
                    verticalAlignment: VerticalAlignment.Center
                }
                // The slider component
                Slider {
                    id: radius_value
                    leftMargin: 10
                    rightMargin: 10
                    horizontalAlignment: HorizontalAlignment.Fill
                    verticalAlignment: VerticalAlignment.Center
                    
                    layoutProperties: StackLayoutProperties {
                        spaceQuota: 1
                    }
                    objectName: "sl_radius"
                    toValue: 3000
                    fromValue: 10.0
                    onValueChanged: {
                        _newLocation.map_updateCircle(Math.round(immediateValue))
                    }
                    value: 100.0
                
                }
                
                // At the maximum position of the slider means day-time so an image of a
                // sun is added to illustrate this.
                ImageView {
                    imageSource: "asset:///images/ic_zoom_in.png"
                    verticalAlignment: VerticalAlignment.Center
                
                } // Sun icon Image
            } // Slider Container
            
            Container {
                verticalAlignment: VerticalAlignment.Top
                preferredHeight: 120.0
                horizontalAlignment: HorizontalAlignment.Fill
                background: Color.DarkGray
                opacity: 0.5
            }
            
            Container {
                layout: StackLayout {
                    orientation: LayoutOrientation.LeftToRight
                }
                topPadding: 30
                
                verticalAlignment: VerticalAlignment.Top
                horizontalAlignment: HorizontalAlignment.Center
                Label {
                    text: " " + Math.round(radius_value.immediateValue) + qsTr(" Meters") + Retranslate.onLanguageChanged
                    //                        textStyle.color: Color.Red
                    verticalAlignment: VerticalAlignment.Center
                    horizontalAlignment: HorizontalAlignment.Center
                    textStyle.color: Color.Blue
                    textStyle.fontSize: FontSize.Large
                }
            }
            
            Container {
                layout: StackLayout {
                }
                verticalAlignment: VerticalAlignment.Center
                horizontalAlignment: HorizontalAlignment.Center
                objectName: "container_getting_location"
                Label {
                    text: qsTr("Getting Current Location...") + Retranslate.onLanguageChanged	            
                    verticalAlignment: VerticalAlignment.Center
                    horizontalAlignment: HorizontalAlignment.Center
                    textStyle.color: Color.Blue
                    textStyle.fontSize: FontSize.Large
                }
            }
            
            Container {
                layout: StackLayout {
                }
                leftPadding: 10
                topPadding: 10
                verticalAlignment: VerticalAlignment.Top
                horizontalAlignment: HorizontalAlignment.Left
                objectName: "container_home"
                enabled: false
                ImageButton {
                    defaultImageSource: "asset:///images/ic_go_home.png"
                    onClicked: {
                        _newLocation.goHome();
                    }
                }
            }
            
            Container {
                layout: StackLayout {
                }
                rightPadding: 10
                topPadding: 10
                verticalAlignment: VerticalAlignment.Top
                horizontalAlignment: HorizontalAlignment.Right
                objectName: "container_search"
                enabled: false
                ImageButton {
                    defaultImageSource: "asset:///images/ic_search_map.png"
                    onClicked: {
                        _newLocation.searchMap();
                    }
                }
            }
        
        
        } // container
    
    
    } // page
}
